@@ -33,9 +33,12 @@ fi
 
 cat "$service_certificate" "$ca_path" "$service_key" > "$service_pem"
 
-haproxy_container_name=$($container_cli ps --format="{{.Names}}" | grep haproxy)
+haproxy_container_name=$($container_cli ps --format="{{.Names}}" | grep -w -E 'haproxy(-bundle-.*-[0-9]+)?')
 
 if [ "$ACTION" == "reload" ]; then
+    # Refresh the cert at the mount-point
+    $container_cli cp $service_pem "$haproxy_container_name:/var/lib/kolla/config_files/src-tls/$service_pem"
+
     # Copy the new cert from the mount-point to the real path
     $container_cli exec "$haproxy_container_name" cp "/var/lib/kolla/config_files/src-tls$service_pem" "$service_pem"
 
