@@ -195,6 +195,25 @@ describe 'tripleo::profile::base::cinder::volume' do
         end
       end
 
+        context 'with only vxflexos' do
+        before :each do
+          params.merge!({
+            :cinder_enable_dellemc_vxflexos_backend => true,
+            :cinder_enable_iscsi_backend            => false,
+          })
+        end
+        it 'should configure only vxflexos' do
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellemc_vxflexos')
+          is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::iscsi')
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume')
+          is_expected.to contain_class('tripleo::profile::base::cinder')
+          is_expected.to contain_class('cinder::volume')
+          is_expected.to contain_class('cinder::backends').with(
+            :enabled_backends => ['tripleo_dellemc_vxflexos']
+          )
+        end
+      end
+
       context 'with only netapp' do
         before :each do
           params.merge!({
@@ -300,6 +319,7 @@ describe 'tripleo::profile::base::cinder::volume' do
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::dellemc_xtremio')
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::dellsc')
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::dellemc_powermax')
+          is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::dellemc_vxflexos')
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::netapp')
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::veritas_hyperscale')
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::nfs')
@@ -324,6 +344,7 @@ describe 'tripleo::profile::base::cinder::volume' do
             :cinder_enable_dellemc_sc_backend       => true,
             :cinder_enable_dellsc_backend           => true,
             :cinder_enable_dellemc_xtremio_backend  => true,
+            :cinder_enable_dellemc_vxflexos_backend => true,
             :cinder_enable_netapp_backend           => true,
             :cinder_enable_vrts_hs_backend          => true,
           })
@@ -335,6 +356,7 @@ describe 'tripleo::profile::base::cinder::volume' do
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellemc_xtremio')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellsc')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellemc_powermax')
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellemc_vxflexos')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::netapp')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::veritas_hyperscale')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::nfs')
@@ -344,7 +366,7 @@ describe 'tripleo::profile::base::cinder::volume' do
           is_expected.to contain_class('cinder::volume')
           is_expected.to contain_class('cinder::backends').with(
             :enabled_backends => ['tripleo_iscsi', 'tripleo_ceph', 'tripleo_pure', 'tripleo_dellsc', 'tripleo_dellemc_sc','tripleo_dellemc_powermax',
-                                  'tripleo_dellemc_xtremio', 'tripleo_netapp','tripleo_nfs','Veritas_HyperScale']
+                                  'tripleo_dellemc_vxflexos', 'tripleo_dellemc_xtremio', 'tripleo_netapp','tripleo_nfs','Veritas_HyperScale']
           )
         end
       end
