@@ -43,6 +43,8 @@ eos
         is_expected.to contain_class('tripleo::profile::base::nova::authtoken')
         is_expected.to_not contain_class('nova::api')
         is_expected.to_not contain_class('nova::cors')
+        is_expected.to_not contain_class('nova::pci')
+        is_expected.to_not contain_class('nova::vendordata')
         is_expected.to_not contain_class('nova::network::neutron')
         is_expected.to_not contain_class('nova::wsgi::apache_api')
       }
@@ -63,6 +65,8 @@ eos
           :nova_metadata_wsgi_enabled => true
         )
         is_expected.to contain_class('nova::cors')
+        is_expected.to contain_class('nova::pci')
+        is_expected.to contain_class('nova::vendordata')
         is_expected.to contain_class('nova::network::neutron')
         is_expected.to contain_class('nova::wsgi::apache_api')
       }
@@ -81,6 +85,8 @@ eos
         is_expected.to_not contain_class('nova::cell_v2::simple_setup')
         is_expected.to_not contain_class('nova::api')
         is_expected.to_not contain_class('nova::cors')
+        is_expected.to_not contain_class('nova::pci')
+        is_expected.to_not contain_class('nova::vendordata')
         is_expected.to_not contain_class('nova::network::neutron')
         is_expected.to_not contain_class('nova::wsgi::apache_api')
       }
@@ -101,6 +107,8 @@ eos
           :nova_metadata_wsgi_enabled => true
         )
         is_expected.to contain_class('nova::cors')
+        is_expected.to contain_class('nova::pci')
+        is_expected.to contain_class('nova::vendordata')
         is_expected.to contain_class('nova::network::neutron')
         is_expected.to contain_class('nova::wsgi::apache_api')
       }
